@@ -81,6 +81,8 @@ int main(int argc, char *argv[])
 			xres = atoi(argv[++i]);
 		} else if (!strcmp(argv[i], "-y")) {
 			yres = atoi(argv[++i]);
+		} else if (!strcmp(argv[i], "-p")) {
+			pulsating = 1;
 		} else {
 			exit(1);
 		}
